@@ -16,10 +16,76 @@ def parsed_api(url):
     
     return parsed
 
+def count_state(api_data):
+    data = {} 
+    count = 0
+    user_state = {}
+    
+    for i in range (len(api_data)):
+        temp = api_data[i]['user']['login'] 
+        count+=1
+        if temp not in data: 
+            data[temp] = set() 
+        data[temp].add(count) 
+        
+    for user, value in data.items(): 
+        user_state[user] = set() 
+        user_state[user] = len(value) 
+    
+    return user_state
+
+def count_state_commit(api_data):
+    data = {} 
+    count = 0
+    user_state = {}
+    for i in range (len(api_data)):
+        temp = api_data[i]['author']['login'] 
+        count+=1
+        if temp not in data: 
+            data[temp] = set() 
+        data[temp].add(count) 
+    for user , value in data.items(): 
+        user_state[user] = set() 
+        user_state[user] = len(value) 
+    return user_state
+
+def count_loc(api_commit):
+    locArr = []
+    for i in range(len(api_commit)):
+        a = api_commit[i]['weeks']
+        arrA = []
+        for j in range(len(api_commit[i]['weeks'])):
+            tempDict = api_commit[i]['weeks'][j]
+            arr = []
+            for key, value in tempDict.items():
+                arr.append(value)
+            arrA.append(arr)
+        locArr.append(arrA)   
+    ArrAdd = []
+    ArrDel = []
+    for i in range(len(locArr)):
+        tempArr= []
+        tempArr2=[]
+        for j in range(len(locArr[i])):
+            tempArr.append(locArr[i][j][1])
+            tempArr2.append(locArr[i][j][2])
+        ArrAdd.append(tempArr)
+        ArrDel.append(tempArr2)
+    result_list = []
+    for i in range(len(ArrAdd)):
+        result_list.append(list(map(add, ArrAdd[i], ArrDel[i])))
+    loc_tot = [ ]
+    for i in range(len(result_list)):
+        loc_tot.append(sum(result_list[i]))
+    LOC_dict = {}
+    for i in range(len(loc_tot)):
+        developer = api_commit[i]['author']['login']
+        LOC_dict[developer] = loc_tot[i]
+    return LOC_dict
+
 def countIssue(dt_upt, df_agg_issue):
     today = datetime.today()
     one_day = timedelta(days=1)
-    
     dates = dt_upt.date()
     week = 0
     while dates != today.date():
@@ -30,7 +96,6 @@ def countIssue(dt_upt, df_agg_issue):
             for j in range(7):
                 if df_agg_issue['date'][i].date() == dates:
                     issue+=df_agg_issue['Issue'][i]
-                    
                 if dates == today.date():
                     if df_agg_issue['User Name'][i] not in dict_issue_weekly:
                         dict_issue_weekly[df_agg_issue['User Name'][i]] = issue
@@ -38,7 +103,7 @@ def countIssue(dt_upt, df_agg_issue):
                         dict_issue_weekly[df_agg_issue['User Name'][i]] = dict_issue_weekly[df_agg_issue['User Name'][i]] + issue
                         
                     df_issue = pd.DataFrame(list(dict_issue_weekly.items()), columns=['User Name','Issue Total'])
-                    save = df_issue.to_csv(r'E:/TA/Hasil/Issue/Base/issue_week{counter}.csv'.format(counter = week), index = None, header= True)
+                    save = df_issue.to_csv(r'app/hasil/Issue/Base/issue_week{counter}.csv'.format(counter = week), index = None, header= True)
                     break; break
                     
                 dates = dates + one_day
@@ -90,7 +155,7 @@ def countPR(dt_upt, df_agg_pull):
             dates = dates - timedelta(days=7)
 
         df_pull = pd.DataFrame(list(dict_pull_weekly.items()), columns=['User Name','PR Total'])
-        save = df_pull.to_csv(r'E:/TA/Hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
+        save = df_pull.to_csv(r'app/hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
         dates = dates + timedelta(days=7)
         
     return week
