@@ -2,6 +2,12 @@
 
 from HandlerAPI.HandlerAPI import parsed_api
 
+from HandlerAPI.HandlerAPI import count_state
+
+from HandlerAPI.HandlerAPI import count_state_commit
+
+from HandlerAPI.HandlerAPI import count_loc
+
 from HandlerAPI.HandlerAPI import countIssue
 
 from HandlerAPI.HandlerAPI import countPR
@@ -12,6 +18,9 @@ from HandlerAPI.HandlerAPI import countLOC
 
 __all__ = [
     'parsed_api',
+    'count_state',
+    'count_state_commit',
+    'count_loc',
     'countIssue',
     'countPR',
     'countCommit',
